==> haskell-snap-server-1.1.0.0-46-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-snap-server.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: snap-server
version: 1.1.0.0
id: snap-server-1.1.0.0-B2w5DhjGbVR2lpKjHnLQpS
key: snap-server-1.1.0.0-B2w5DhjGbVR2lpKjHnLQpS
license: BSD-3-Clause
maintainer: snap@snapframework.com
author: Snap Framework Authors  (see CONTRIBUTORS)
homepage: http://snapframework.com/
synopsis: A web server for the Snap Framework
description:
    Snap is a simple and fast web development framework and server written in
    Haskell. For more information or to download the latest version, you can
    visit the Snap project website at <http://snapframework.com/>.
    .
    The Snap HTTP server is a high performance web server library written in
    Haskell. Together with the @snap-core@ library upon which it depends, it
    provides a clean and efficient Haskell programming interface to the HTTP
    protocol.
category: Web, Snap, IO-Streams
abi: 89eeabc5f65d7e398baa0ba42dfb2264
exposed: True
exposed-modules:
    Snap.Http.Server Snap.Http.Server.Config Snap.Http.Server.Types
    Snap.Internal.Http.Server.Config Snap.Internal.Http.Server.Types
    System.FastLogger
hidden-modules: Paths_snap_server Control.Concurrent.Extended
                Snap.Internal.Http.Server.Address Snap.Internal.Http.Server.Clock
                Snap.Internal.Http.Server.Common Snap.Internal.Http.Server.Date
                Snap.Internal.Http.Server.Parser Snap.Internal.Http.Server.Session
                Snap.Internal.Http.Server.Socket Snap.Internal.Http.Server.Thread
                Snap.Internal.Http.Server.TimeoutManager
                Snap.Internal.Http.Server.TLS System.SendFile System.SendFile.Linux
import-dirs: /usr/lib/ghc-8.4.3/site-local/snap-server-1.1.0.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/snap-server-1.1.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/snap-server-1.1.0.0
hs-libraries: HSsnap-server-1.1.0.0-B2w5DhjGbVR2lpKjHnLQpS
depends:
    attoparsec-0.13.2.2-5oKqcFqqk8HLoRElqn64fK base-4.11.1.0
    blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028 bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    clock-0.7.2-ErKmPTjVISxJnEb9XKUAOs containers-0.5.11.0
    filepath-1.4.2 io-streams-1.5.0.1-2bVNxAA2r1O57zSFpx0loj
    io-streams-haproxy-1.0.0.2-7768sS8XvoKqM7hY9ZYEV
    lifted-base-0.2.3.12-KjumfQ58uBm8QT3h2l4nDA mtl-2.2.2
    network-2.7.0.2-8yE8vwBlEy1KZPVD4sTAn
    old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh
    snap-core-1.0.3.2-6CH3hXX10wT4aYt0Ez2ehc text-1.2.3.0 time-1.8.0.2
    unix-compat-0.5.1-IZ2l0C7CE13FdrCF8rJfBj
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq unix-2.7.2.2
abi-depends: attoparsec-0.13.2.2-5oKqcFqqk8HLoRElqn64fK=fff7ae21f45c1b0af12007963cebbf81
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=f952a1ec5abae3e4435518edbfd82e4e
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=0a5994e39a32f328ff4f350b25844411
             clock-0.7.2-ErKmPTjVISxJnEb9XKUAOs=aea2e14c40bb78b61c7d4fb8ecb421a3
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             io-streams-1.5.0.1-2bVNxAA2r1O57zSFpx0loj=c29d11fe530951aff4dc7b9acd92aa68
             io-streams-haproxy-1.0.0.2-7768sS8XvoKqM7hY9ZYEV=c5fd224bae044fc0597e980e7d5dadbe
             lifted-base-0.2.3.12-KjumfQ58uBm8QT3h2l4nDA=bb0bc40b0f20c1d20c198f711f59633a
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             network-2.7.0.2-8yE8vwBlEy1KZPVD4sTAn=90fa8650caae170586ac66be24e6a39f
             old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh=576647ddb2b9fe32850edc158395e14c
             snap-core-1.0.3.2-6CH3hXX10wT4aYt0Ez2ehc=0ff7b18ba06eb6280a699cf0bf7d9d0f
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             unix-compat-0.5.1-IZ2l0C7CE13FdrCF8rJfBj=2a0e42b97373c43e88dbd8b7b82c7192
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             unix-2.7.2.2=f81aa481840dadf9c364a1cea96978c0
haddock-interfaces: /usr/share/doc/haskell-snap-server/html/snap-server.haddock
haddock-html: /usr/share/doc/haskell-snap-server/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-snap-server-1.1.0.0-50-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-snap-server.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: snap-server
version: 1.1.0.0
id: snap-server-1.1.0.0-H85eNSLe732GRIAxa94RVS
key: snap-server-1.1.0.0-H85eNSLe732GRIAxa94RVS
license: BSD-3-Clause
maintainer: snap@snapframework.com
author: Snap Framework Authors  (see CONTRIBUTORS)
homepage: http://snapframework.com/
synopsis: A web server for the Snap Framework
description:
    Snap is a simple and fast web development framework and server written in
    Haskell. For more information or to download the latest version, you can
    visit the Snap project website at <http://snapframework.com/>.
    .
    The Snap HTTP server is a high performance web server library written in
    Haskell. Together with the @snap-core@ library upon which it depends, it
    provides a clean and efficient Haskell programming interface to the HTTP
    protocol.
category: Web, Snap, IO-Streams
abi: fd574d24abf04e1d28bad267221e28f0
exposed: True
exposed-modules:
    Snap.Http.Server Snap.Http.Server.Config Snap.Http.Server.Types
    Snap.Internal.Http.Server.Config Snap.Internal.Http.Server.Types
    System.FastLogger
hidden-modules: Paths_snap_server Control.Concurrent.Extended
                Snap.Internal.Http.Server.Address Snap.Internal.Http.Server.Clock
                Snap.Internal.Http.Server.Common Snap.Internal.Http.Server.Date
                Snap.Internal.Http.Server.Parser Snap.Internal.Http.Server.Session
                Snap.Internal.Http.Server.Socket Snap.Internal.Http.Server.Thread
                Snap.Internal.Http.Server.TimeoutManager
                Snap.Internal.Http.Server.TLS System.SendFile System.SendFile.Linux
import-dirs: /usr/lib/ghc-8.4.3/site-local/snap-server-1.1.0.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/snap-server-1.1.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/snap-server-1.1.0.0
hs-libraries: HSsnap-server-1.1.0.0-H85eNSLe732GRIAxa94RVS
depends:
    attoparsec-0.13.2.2-LRi8ukEwwi1GyId6oqTEFJ base-4.11.1.0
    blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028 bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    clock-0.7.2-ErKmPTjVISxJnEb9XKUAOs containers-0.5.11.0
    filepath-1.4.2 io-streams-1.5.0.1-IQSRKdqvO3e5ntUOI8deUZ
    io-streams-haproxy-1.0.0.2-4IG5Rn1ilk8CASYhYvfD6O
    lifted-base-0.2.3.12-KjumfQ58uBm8QT3h2l4nDA mtl-2.2.2
    network-2.7.0.2-8yE8vwBlEy1KZPVD4sTAn
    old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh
    snap-core-1.0.3.2-H0IZ7ihVK3ZDV5rgSyZbAa text-1.2.3.0 time-1.8.0.2
    unix-compat-0.5.1-IZ2l0C7CE13FdrCF8rJfBj
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq unix-2.7.2.2
abi-depends: attoparsec-0.13.2.2-LRi8ukEwwi1GyId6oqTEFJ=b8f8a17746566009aae6e9799affc625
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=f952a1ec5abae3e4435518edbfd82e4e
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=0a5994e39a32f328ff4f350b25844411
             clock-0.7.2-ErKmPTjVISxJnEb9XKUAOs=aea2e14c40bb78b61c7d4fb8ecb421a3
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             io-streams-1.5.0.1-IQSRKdqvO3e5ntUOI8deUZ=8d48093b7ba3c027f28894a69172c076
             io-streams-haproxy-1.0.0.2-4IG5Rn1ilk8CASYhYvfD6O=f97e5dd1f751cb4e8701560a447a715b
             lifted-base-0.2.3.12-KjumfQ58uBm8QT3h2l4nDA=bb0bc40b0f20c1d20c198f711f59633a
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             network-2.7.0.2-8yE8vwBlEy1KZPVD4sTAn=90fa8650caae170586ac66be24e6a39f
             old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh=576647ddb2b9fe32850edc158395e14c
             snap-core-1.0.3.2-H0IZ7ihVK3ZDV5rgSyZbAa=f9a75ce107470bb8eb89faff19c688b4
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             unix-compat-0.5.1-IZ2l0C7CE13FdrCF8rJfBj=2a0e42b97373c43e88dbd8b7b82c7192
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             unix-2.7.2.2=f81aa481840dadf9c364a1cea96978c0
haddock-interfaces: /usr/share/doc/haskell-snap-server/html/snap-server.haddock
haddock-html: /usr/share/doc/haskell-snap-server/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
